Documentation
¶
Overview ¶
Package instrumenter provides an interface for observing cache, ratelimit and HTTP operations.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NullFinish ¶ added in v0.33.0
func NullFinish(error)
NullFinish helper when no error handling is needed.
func NullInstrumenter ¶
NullInstrumenter is a no-op instrumenter.
func ObserveKey ¶ added in v0.33.0
func ObserveKey(ctx context.Context, i Instrumenter, op, key string) func(error)
ObserveKey helper for instrumenting operations with a single key argument.
Types ¶
type Instrumenter ¶
Instrumenter defines function type that can be used for instrumentation. This function should return a function with no argument as a callback for finished execution.
func CombinedInstrumenter ¶
func CombinedInstrumenter(instr ...Instrumenter) Instrumenter
CombinedInstrumenter is an instrumenter that combines multiple instrumenters.
Click to show internal directories.
Click to hide internal directories.